# swagger_client.CustomerApi

All URIs are relative to *https://reputationcrm.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_customer_automatic**](CustomerApi.md#create_customer_automatic) | **POST** /createCustomerAutomatic | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)
[**create_customer_automatic_with_delay_review_request**](CustomerApi.md#create_customer_automatic_with_delay_review_request) | **POST** /createCustomerAutomaticWithDelayReviewRequest | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)
[**create_customer_immediate_first_review_request**](CustomerApi.md#create_customer_immediate_first_review_request) | **POST** /createCustomerImmediateFirstReviewRequest | Create a Customer AND Feedback / Review Requests
[**create_customer_manual_schedule_one_review_request**](CustomerApi.md#create_customer_manual_schedule_one_review_request) | **POST** /createCustomerManualScheduleOneReviewRequest | Create a Customer AND a one Feedback / Review Request (Manual Scheduling)
[**delete_customer**](CustomerApi.md#delete_customer) | **DELETE** /deleteCustomer | Delete ONE Customer record
[**get_all_customers_bycompany_id**](CustomerApi.md#get_all_customers_bycompany_id) | **GET** /getAllCustomersBycompanyId | Get Information on ALL Customers of a Company / Location / Feedback Page
[**get_customers_who_have_not_yet_submitted_review**](CustomerApi.md#get_customers_who_have_not_yet_submitted_review) | **GET** /getCustomersWhoHaveNotYetSubmittedReview | Get a list of Customers who have not yet submitted their Review / Feedback
[**get_single_customer**](CustomerApi.md#get_single_customer) | **GET** /getSingleCustomer | Get Information of ONE Customer
[**update_customer**](CustomerApi.md#update_customer) | **PUT** /updateCustomer | Update the record of ONE Customer


# **create_customer_automatic**
> str create_customer_automatic(companyid, firstname, lastname, sendtype, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)

Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)

This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH NO DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -> Notifications -> Email AND SMS Tabs 

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
companyid = 'companyid_example' # str | Company ID
firstname = 'firstname_example' # str | Customer First Name
lastname = 'lastname_example' # str | Customer Last Name
sendtype = '1' # str | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
email = 'email_example' # str | Customer Email (optional)
mobile = 'mobile_example' # str | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional)
address = 'address_example' # str | Customer Postal Address (optional)
zipcode = 'zipcode_example' # str | Customer Zipcode (optional)
city = 'city_example' # str | Customer City (optional)
state = 'state_example' # str | Customer State / Province / Region (optional)
country = 'country_example' # str | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional)
language = 'language_example' # str | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional)
notes = 'notes_example' # str | Additional Customer Notes (optional)

try:
    # Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)
    api_response = api_instance.create_customer_automatic(companyid, firstname, lastname, sendtype, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CustomerApi->create_customer_automatic: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **str**| Company ID | 
 **firstname** | **str**| Customer First Name | 
 **lastname** | **str**| Customer Last Name | 
 **sendtype** | **str**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **email** | **str**| Customer Email | [optional] 
 **mobile** | **str**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **str**| Customer Postal Address | [optional] 
 **zipcode** | **str**| Customer Zipcode | [optional] 
 **city** | **str**| Customer City | [optional] 
 **state** | **str**| Customer State / Province / Region | [optional] 
 **country** | **str**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **str**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **str**| Additional Customer Notes | [optional] 

### Return type

**str**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_customer_automatic_with_delay_review_request**
> create_customer_automatic_with_delay_review_request(companyid, firstname, lastname, sendtype, delay_before_first_review_request, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)

Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)

This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH A DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -> Notifications -> Email AND SMS Tabs 

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
companyid = 'companyid_example' # str | Company ID
firstname = 'firstname_example' # str | Customer First Name
lastname = 'lastname_example' # str | Customer Last Name
sendtype = '1' # str | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
delay_before_first_review_request = 'delay_before_first_review_request_example' # str | Delay before sending the first Feedback / Review Request (Allowed values: \"immediately\", \"X minute\", \"X hour\", \"X day\", \"X week\", \"X month\", \"X year\") 
email = 'email_example' # str | Customer Email (optional)
mobile = 'mobile_example' # str | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional)
address = 'address_example' # str | Customer Postal Address (optional)
zipcode = 'zipcode_example' # str | Customer Zipcode (optional)
city = 'city_example' # str | Customer City (optional)
state = 'state_example' # str | Customer State / Province / Region (optional)
country = 'country_example' # str | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional)
language = 'language_example' # str | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional)
notes = 'notes_example' # str | Additional Customer Notes (optional)

try:
    # Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)
    api_instance.create_customer_automatic_with_delay_review_request(companyid, firstname, lastname, sendtype, delay_before_first_review_request, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)
except ApiException as e:
    print("Exception when calling CustomerApi->create_customer_automatic_with_delay_review_request: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **str**| Company ID | 
 **firstname** | **str**| Customer First Name | 
 **lastname** | **str**| Customer Last Name | 
 **sendtype** | **str**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **delay_before_first_review_request** | **str**| Delay before sending the first Feedback / Review Request (Allowed values: \&quot;immediately\&quot;, \&quot;X minute\&quot;, \&quot;X hour\&quot;, \&quot;X day\&quot;, \&quot;X week\&quot;, \&quot;X month\&quot;, \&quot;X year\&quot;)  | 
 **email** | **str**| Customer Email | [optional] 
 **mobile** | **str**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **str**| Customer Postal Address | [optional] 
 **zipcode** | **str**| Customer Zipcode | [optional] 
 **city** | **str**| Customer City | [optional] 
 **state** | **str**| Customer State / Province / Region | [optional] 
 **country** | **str**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **str**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **str**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_customer_immediate_first_review_request**
> create_customer_immediate_first_review_request(companyid, firstname, lastname, sendtype, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)

Create a Customer AND Feedback / Review Requests

This API call creates a Customer in Reputation Builder AND Feedback / Review Request #1 (Email #1 AND/OR SMS #1 ONLY). Feedback / Review Request(s) are then sent immediately 

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
companyid = 'companyid_example' # str | Company ID
firstname = 'firstname_example' # str | Customer First Name
lastname = 'lastname_example' # str | Customer Last Name
sendtype = '1' # str | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
email = 'email_example' # str | Customer Email (optional)
mobile = 'mobile_example' # str | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional)
address = 'address_example' # str | Customer Postal Address (optional)
zipcode = 'zipcode_example' # str | Customer Zipcode (optional)
city = 'city_example' # str | Customer City (optional)
state = 'state_example' # str | Customer State / Province / Region (optional)
country = 'country_example' # str | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional)
language = 'language_example' # str | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional)
notes = 'notes_example' # str | Additional Customer Notes (optional)

try:
    # Create a Customer AND Feedback / Review Requests
    api_instance.create_customer_immediate_first_review_request(companyid, firstname, lastname, sendtype, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)
except ApiException as e:
    print("Exception when calling CustomerApi->create_customer_immediate_first_review_request: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **str**| Company ID | 
 **firstname** | **str**| Customer First Name | 
 **lastname** | **str**| Customer Last Name | 
 **sendtype** | **str**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **email** | **str**| Customer Email | [optional] 
 **mobile** | **str**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **str**| Customer Postal Address | [optional] 
 **zipcode** | **str**| Customer Zipcode | [optional] 
 **city** | **str**| Customer City | [optional] 
 **state** | **str**| Customer State / Province / Region | [optional] 
 **country** | **str**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **str**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **str**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_customer_manual_schedule_one_review_request**
> create_customer_manual_schedule_one_review_request(companyid, firstname, lastname, sendtype, emailnumber, smsnumber, scheduledate, scheduletime, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)

Create a Customer AND a one Feedback / Review Request (Manual Scheduling)

This API call creates a Customer in Reputation Builder AND one Feedback / Review Request. You decide which Feedback / Review Request # to send, the sending method (Email or SMS) and you have full control of the sending date and time 

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
companyid = 'companyid_example' # str | Company ID
firstname = 'firstname_example' # str | Customer First Name
lastname = 'lastname_example' # str | Customer Last Name
sendtype = '1' # str | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\"  (default to 1)
emailnumber = '1' # str | Set which Email Feedback / Requests will be sent (Allowed values: \"1\", \"2\", \"3\")  (default to 1)
smsnumber = '1' # str | Set which SMS Feedback / Requests will be sent (Allowed values: \"1\", \"2\", \"3\")  (default to 1)
scheduledate = 'scheduledate_example' # str | Schedule date (yyyy/mm/dd) 
scheduletime = 'scheduletime_example' # str | Schedule time (HH:MM 24 hours format) 
email = 'email_example' # str | Customer Email (optional)
mobile = 'mobile_example' # str | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  (optional)
address = 'address_example' # str | Customer Postal Address (optional)
zipcode = 'zipcode_example' # str | Customer Zipcode (optional)
city = 'city_example' # str | Customer City (optional)
state = 'state_example' # str | Customer State / Province / Region (optional)
country = 'country_example' # str | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  (optional)
language = 'language_example' # str | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  (optional)
notes = 'notes_example' # str | Additional Customer Notes (optional)

try:
    # Create a Customer AND a one Feedback / Review Request (Manual Scheduling)
    api_instance.create_customer_manual_schedule_one_review_request(companyid, firstname, lastname, sendtype, emailnumber, smsnumber, scheduledate, scheduletime, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language, notes=notes)
except ApiException as e:
    print("Exception when calling CustomerApi->create_customer_manual_schedule_one_review_request: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **str**| Company ID | 
 **firstname** | **str**| Customer First Name | 
 **lastname** | **str**| Customer Last Name | 
 **sendtype** | **str**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **emailnumber** | **str**| Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;)  | [default to 1]
 **smsnumber** | **str**| Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;)  | [default to 1]
 **scheduledate** | **str**| Schedule date (yyyy/mm/dd)  | 
 **scheduletime** | **str**| Schedule time (HH:MM 24 hours format)  | 
 **email** | **str**| Customer Email | [optional] 
 **mobile** | **str**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **str**| Customer Postal Address | [optional] 
 **zipcode** | **str**| Customer Zipcode | [optional] 
 **city** | **str**| Customer City | [optional] 
 **state** | **str**| Customer State / Province / Region | [optional] 
 **country** | **str**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **str**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **str**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_customer**
> delete_customer(customerid)

Delete ONE Customer record

This API call deletes an existing Customer from Reputation Builder. It will also delete all Email / SMS Requests still in the Queue

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
customerid = 'customerid_example' # str | Customer ID

try:
    # Delete ONE Customer record
    api_instance.delete_customer(customerid)
except ApiException as e:
    print("Exception when calling CustomerApi->delete_customer: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **str**| Customer ID | 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_all_customers_bycompany_id**
> list[Customer] get_all_customers_bycompany_id(companyid)

Get Information on ALL Customers of a Company / Location / Feedback Page

This API call returns information from Reputation Builder on ALL existing Customers of a Company / Location / Feedback Page

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
companyid = 'companyid_example' # str | Company ID

try:
    # Get Information on ALL Customers of a Company / Location / Feedback Page
    api_response = api_instance.get_all_customers_bycompany_id(companyid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CustomerApi->get_all_customers_bycompany_id: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **str**| Company ID | 

### Return type

[**list[Customer]**](Customer.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_customers_who_have_not_yet_submitted_review**
> list[CustomerWhoHaveNotResponded] get_customers_who_have_not_yet_submitted_review(companyid)

Get a list of Customers who have not yet submitted their Review / Feedback

This API call returns the list of Customers of a Company / Location / Feedback Page who have not yet responded to Feedback / Review Requests

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
companyid = 'companyid_example' # str | Company ID

try:
    # Get a list of Customers who have not yet submitted their Review / Feedback
    api_response = api_instance.get_customers_who_have_not_yet_submitted_review(companyid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CustomerApi->get_customers_who_have_not_yet_submitted_review: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **str**| Company ID | 

### Return type

[**list[CustomerWhoHaveNotResponded]**](CustomerWhoHaveNotResponded.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_single_customer**
> list[Customer] get_single_customer(customerid)

Get Information of ONE Customer

This API call returns information from Reputation Builder on ONE existing Customer

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
customerid = 'customerid_example' # str | Customer ID

try:
    # Get Information of ONE Customer
    api_response = api_instance.get_single_customer(customerid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CustomerApi->get_single_customer: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **str**| Customer ID | 

### Return type

[**list[Customer]**](Customer.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_customer**
> update_customer(customerid, firstname, lastname, notes, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language)

Update the record of ONE Customer

This API call updates information from Reputation Builder on ONE existing Customer

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CustomerApi(swagger_client.ApiClient(configuration))
customerid = 'customerid_example' # str | Customer ID
firstname = 'firstname_example' # str | Customer First Name
lastname = 'lastname_example' # str | Customer Last Name
notes = 'notes_example' # str | Additional Customer Notes
email = 'email_example' # str | Customer Email (optional)
mobile = 'mobile_example' # str | Customer Mobile Phone (optional)
address = 'address_example' # str | Customer Postal Address (optional)
zipcode = 'zipcode_example' # str | Customer Zipcode (optional)
city = 'city_example' # str | Customer City (optional)
state = 'state_example' # str | Customer State / Province / Region (optional)
country = 'country_example' # str | Customer Country (optional)
language = 'language_example' # str | Customer Language (optional)

try:
    # Update the record of ONE Customer
    api_instance.update_customer(customerid, firstname, lastname, notes, email=email, mobile=mobile, address=address, zipcode=zipcode, city=city, state=state, country=country, language=language)
except ApiException as e:
    print("Exception when calling CustomerApi->update_customer: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **str**| Customer ID | 
 **firstname** | **str**| Customer First Name | 
 **lastname** | **str**| Customer Last Name | 
 **notes** | **str**| Additional Customer Notes | 
 **email** | **str**| Customer Email | [optional] 
 **mobile** | **str**| Customer Mobile Phone | [optional] 
 **address** | **str**| Customer Postal Address | [optional] 
 **zipcode** | **str**| Customer Zipcode | [optional] 
 **city** | **str**| Customer City | [optional] 
 **state** | **str**| Customer State / Province / Region | [optional] 
 **country** | **str**| Customer Country | [optional] 
 **language** | **str**| Customer Language | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

